[English](README.md) | 简体中文

## Ant Chain DAS SDK for Python

## 要求

- Python >= 3.6

## 安装

- **使用 pip 安装(推荐)**

如未安装 `pip`, 请先至pip官网 [pip user guide](https://pip.pypa.io/en/stable/installing/ "pip User Guide") 安装pip .

```bash
# 安装 antchain_sdk_das
pip install antchain_sdk_das
```

## 问题

[提交 Issue](https://github.com/alipay/antchain-openapi-prod-sdk/issues/new)，不符合指南的问题可能会立即关闭。

## 使用说明

[快速使用](https://github.com/alipay/antchain-openapi-prod-sdk)

## 发行说明

每个版本的详细更改记录在[发行说明](./ChangeLog.md)中。

## 相关

- [最新源码](https://github.com/alipay/antchain-openapi-prod-sdk/)

## 许可证

[Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)
